I’ve been trying all weekend to get the latest version of VLLM and MiniMaxAi/MiniMax-M2 on a cluster of Sparks. I’m currently stuck. Wondering if anyone has been able to run MiniMaxAi/MiniMax-M2 on a DGX Spark cluster?
Some more info:
VLLM Image; llm/vllm-openai:nightly-17eb25e3271f8f22a0d8920a8115158495827cba
Ray status output:
======== Autoscaler status: 2025-12-08 00:00:19.931554 ========
Node status
---------------------------------------------------------------
Active:
1 node_e8f39ef4412378d799b591343a1053b769dd7f874db5461be91a34b3
1 node_56cfb88f56b8784f2c5c7a30292f11e1ae48a1a2ad2d289067bc0bde
1 node_2c2d2ee76539602bf33c848a18362ed4f8fdb82bd27370dd6456bf1a
1 node_f5e06b111023ecde2feaeb1855b13c10e9c72c03a4862b34c1710111
Pending:
(no pending nodes)
Recent failures:
(no failures)
Resources
---------------------------------------------------------------
Total Usage:
0.0/80.0 CPU
0.0/4.0 GPU
0B/439.05GiB memory
0B/38.91GiB object_store_memory
....snip....
(EngineCore_DP0 pid=466) (RayWorkerWrapper pid=195, ip=10.0.0.3) INFO 12-08 00:01:13 [layer.py:379] Enabled separate cuda stream for MoE shared_experts [repeated 3x across cluster]
(EngineCore_DP0 pid=466) (RayWorkerWrapper pid=195, ip=10.0.0.3) INFO 12-08 00:01:13 [fp8.py:206] Using Triton backend for FP8 MoE [repeated 3x across cluster]
(EngineCore_DP0 pid=466) (RayWorkerWrapper pid=195, ip=10.0.0.2) INFO 12-08 00:03:35 [gpu_model_runner.py:3602] Model loading took 53.7422 GiB memory and 149.992080 seconds
(EngineCore_DP0 pid=466) (RayWorkerWrapper pid=195, ip=10.0.0.1 INFO 12-08 00:03:38 [default_loader.py:308] Loading weights took 142.18 seconds
When serving MiniMaxAI/MiniMax-M2 on 4x Sparks using vLLM’s OpenAI-compatible API, the model produces corrupted output (infinite repetition inside blocks, token spam, failure to follow instructions), even for trivial prompts. This also occurs when calling the model directly (curl.)
Have you experienced this @eugr on the Sparks with VLLM before?
I’m currently testing it, and will merge into main if I don’t find any issues. So far so good. Lots of improvements, main being reduced image size and much faster container rebuilds.